#[non_exhaustive]pub struct Style {
pub color: Option<TextColor>,
pub shadow_color: Option<u32>,
pub bold: Option<bool>,
pub italic: Option<bool>,
pub underlined: Option<bool>,
pub strikethrough: Option<bool>,
pub obfuscated: Option<bool>,
pub click_event: Option<ClickEvent>,
pub hover_event: Option<HoverEvent>,
pub insertion: Option<String>,
pub font: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.color: Option<TextColor>shadow_color: Option<u32>bold: Option<bool>italic: Option<bool>underlined: Option<bool>strikethrough: Option<bool>obfuscated: Option<bool>click_event: Option<ClickEvent>hover_event: Option<HoverEvent>insertion: Option<String>font: Option<String>Represented as an Identifier.
Implementations
Sourceimpl Style
impl Style
pub fn color(self, value: impl Into<Option<TextColor>>) -> Style
pub fn shadow_color(self, value: impl Into<Option<u32>>) -> Style
pub fn bold(self, value: impl Into<Option<bool>>) -> Style
pub fn italic(self, value: impl Into<Option<bool>>) -> Style
pub fn underlined(self, value: impl Into<Option<bool>>) -> Style
pub fn strikethrough(self, value: impl Into<Option<bool>>) -> Style
pub fn obfuscated(self, value: impl Into<Option<bool>>) -> Style
pub fn click_event(self, value: impl Into<Option<ClickEvent>>) -> Style
pub fn hover_event(self, value: impl Into<Option<HoverEvent>>) -> Style
pub fn insertion(self, value: impl Into<Option<String>>) -> Style
pub fn font(self, value: impl Into<Option<String>>) -> Style
pub fn serialize_map<S>(
&self,
state: &mut <S as Serializer>::SerializeMap,
) -> Result<(), <S as Serializer>::Error>where
S: Serializer,
Sourceimpl Style
impl Style
pub fn new() -> Style
pub fn empty() -> Style
pub fn deserialize(json: &Value) -> Style
Sourcepub fn compare_ansi(&self, after: &Style) -> String
pub fn compare_ansi(&self, after: &Style) -> String
find the necessary ansi code to get from this style to another
Sourcepub fn merged_with(&self, other: &Style) -> Style
pub fn merged_with(&self, other: &Style) -> Style
Returns a new style that is a merge of self and other.
For any field that other does not specify (is None), self’s value is
used.
Sourcepub fn apply_formatting(&mut self, formatting: &ChatFormatting)
pub fn apply_formatting(&mut self, formatting: &ChatFormatting)
Apply a ChatFormatting to this style
pub fn get_html_style(&self) -> String